@@ -1,11 +1,18 @@
-from .model import SpecDir
+from .model import SpecDir, create_spec_dict
 from .app import create_app
+from . import tasks, monkey_patch
 
-__all__ = ("SpecDir", "create_app", "tasks")
+__all__ = (
+    "SpecDir",
+    "create_spec_dict",
+    "create_app",
+    "tasks",
+    "monkey_patch",
+)
 
 __author__ = """Ian Maurer"""
-__email__ = 'ian@genomoncology.com'
-__version__ = '0.1.0'
+__email__ = "ian@genomoncology.com"
+__version__ = "0.8.2"
 
 __uri__ = "http://www.github.com/genomoncology/specd"
 __copyright__ = "Copyright (c) 2018 genomoncology.com"
